package Task::Digest;

use 5.006;
use strict;
use warnings;

our $VERSION = '0.01';

1;
__END__

=head1 NAME

Task::Digest - install Digest modules and dependencies

=head1 VERSION

Task::Digest 0.01

=head1 SYNOPSIS

  cpan Task::Digest

=head1 SEE ALSO

For a good introduction, see:

http://rvl4.ecn.purdue.edu/~kak/courses-i-teach/compsec/NewLectures/Lectures15.pdf

=head1 INTERFACE

none

=head2 EXPORT

None by default.

=head1 DEPENDENCIES

XSLoader

AutoLoader

Data::Dumper

Test::More

File::Spec

File::Temp

bignum

Text::Balanced

Filter::Simple

version

Smart::Comments

Pod::Usage

Getopt::Long

Digest

Digest::MD5

Digest::TransformPath

Digest::SHA1

SHA

MIME::Base64

MIME::Base64::Perl

Digest::SHA2

Digest::Whirlpool

Digest::Perl::MD5

Digest::Perl::MD4

Digest::MD5::M4p

Digest::BubbleBabble

Digest::Tiger

LWP::UserAgent

Digest::MD5::File

Digest::CRC

Digest::Crc32

Algorithm::GDiffDelta

Digest::Adler32

Digest::HMAC

Digest::MD2

MD5

Crypt::IDEA

Crypt::DES

Crypt::Blowfish

Crypt::Blowfish_PP

Crypt::CAST5

Crypt::DES_PP

Crypt::Rijndael

Crypt::TEA

Crypt::Twofish2

Crypt::CBC

Crypt::CBCeasy

Crypt::SmbHash

Digest::DMAC

Digest::EMAC

Digest::Haval256

MIME::Base32

Class::Accessor

Perl::Critic

Sub::Install

Data::OptList

Params::Util

Sub::Exporter

Storable

Test::use::ok

Test::Exception

Digets::SHA

UNIVERSAL::can

Crypt::CFB

Crypt::RC5

Crypt::RC6

RIPEMD160

Crypt::RIPEMD160

String::CRC32

String::CRC

Crypt::OpenSSL::Random

Crypt::OpenSSL::RSA

Crypt::Eksblowfish

Algorithm::RabinKarp

Text::Tabs

File::Stat::Bits

Algorithm::Diff

Digest::MultiHash

Digest::JHash

Digest::ELF

File::Find::Rule

Time::Local

Digest::Hashcash

Digest::CMAC

Digest::ManberHash

Digest::SV1

Digest::DJB

Digest::FNV

Digest::Pearson

Digest::Pearson::PurePerl

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.6.0 or,
at your option, any later version of Perl 5 you may have available.


=cut

1;
